A2uiMessage class sealed
A sealed class representing a message in the A2UI stream.
- Implementers
Constructors
- A2uiMessage.fromJson(JsonMap json)
-
Creates an A2uiMessage from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
a2uiMessageSchema(
Catalog catalog) → Schema - Returns the JSON schema for an A2UI message.