CatalogItem class final

Defines a UI layout type, its schema, and how to build its widget.

Annotations

Constructors

CatalogItem({required String name, required Schema dataSchema, required CatalogWidgetBuilder widgetBuilder, List<ExampleBuilderCallback> exampleData = const [], bool isImplicitlyFlexible = false})
Creates a new CatalogItem.
const

Properties

dataSchema → ObjectSchema
The schema definition for this widget's data.
no setter
exampleData List<ExampleBuilderCallback>
A list of builder functions that each return a JSON string representing an example usage of this widget.
final
hashCode int
The hash code for this object.
no setterinherited
isImplicitlyFlexible bool
Whether this component should be implicitly flexible when placed in a flex container (like Row/Column).
final
name String
The widget type name used in JSON, e.g., 'TextChatMessage'.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widgetBuilder CatalogWidgetBuilder
The builder for this widget.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited