ComponentChildrenBuilder class

A helper widget to build widgets from component data that contains a list of children.

This widget handles two cases for defining children:

  1. An explicit list of child widget IDs.
  2. A template with a data binding to a list of data.

The childrenData can be a List<String> of child IDs, or a JsonMap defining a template structure with path and componentId keys.

Inheritance

Constructors

ComponentChildrenBuilder({required Object? childrenData, required DataContext dataContext, required ChildBuilderCallback buildChild, required GetComponentCallback getComponent, required ExplicitListWidgetBuilder explicitListBuilder, required TemplateListWidgetBuilder templateListWidgetBuilder, Key? key})
Creates a new ComponentChildrenBuilder.
const

Properties

buildChild ChildBuilderCallback
The callback to build a child widget.
final
childrenData Object?
The data that defines the children to build.
final
dataContext DataContext
The data context for the children.
final
explicitListBuilder ExplicitListWidgetBuilder
The builder for an explicit list of children.
final
getComponent GetComponentCallback
The callback to get a component's data by ID.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateListWidgetBuilder TemplateListWidgetBuilder
The builder for a template-based list of children.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited