ConversationContentReceived class final

Fired when new content (text) is received from the LLM.

Inheritance

Constructors

ConversationContentReceived(String text)
Creates a ConversationContentReceived event.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content received.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited