NumericFunction class

Checks if a value is numeric and optionally within a range.

Inheritance

Constructors

NumericFunction()
const

Properties

argumentSchema → Schema
The schema for the arguments this function accepts. Used for validation and tool definition generation for the LLM.
no setteroverride
description String
A human-readable description of what the function does and how to use it.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function as used in expressions (e.g. 'stringFormat').
no setteroverride
returnType ClientFunctionReturnType
The type of value this function returns. Defaults to ClientFunctionReturnType.any.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(JsonMap args, ExecutionContext context) Stream<Object?>
Invokes the function with the given args.
inherited
executeSync(JsonMap args, ExecutionContext _) Object?
Executes the function synchronously.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited