defaultBuilder property
A builder for the widget to display when the surface has no definition.
Implementation
final WidgetBuilder? defaultBuilder;
A builder for the widget to display when the surface has no definition.
final WidgetBuilder? defaultBuilder;