SurfaceAdded class final

Fired when a new surface is created.

Inheritance

Constructors

SurfaceAdded(String surfaceId, SurfaceDefinition definition)
Creates a SurfaceAdded event for the given surfaceId and definition.
const

Properties

definition SurfaceDefinition
The definition of the new surface.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceId String
The ID of the surface that was updated.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited