SurfaceHost class abstract interface

An interface for a host that manages UI surfaces.

This host provides updates when surfaces are added, removed, or changed. It also acts as a factory for SurfaceContexts, which provide access to the state of minimal, individual surfaces.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceUpdates Stream<SurfaceUpdate>
A stream of updates for the surfaces managed by this host.
no setter

Methods

contextFor(String surfaceId) SurfaceContext
Returns a SurfaceContext for the surface with the given surfaceId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited