SynchronousClientFunction class abstract

A base class for synchronous client functions.

Implementers should override executeSync to provide the synchronous logic.

Implemented types
Implementers

Constructors

SynchronousClientFunction()
const

Properties

argumentSchema → Schema
The schema for the arguments this function accepts. Used for validation and tool definition generation for the LLM.
no setterinherited
description String
A human-readable description of what the function does and how to use it.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function as used in expressions (e.g. 'stringFormat').
no setterinherited
returnType ClientFunctionReturnType
The type of value this function returns. Defaults to ClientFunctionReturnType.any.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute(JsonMap args, ExecutionContext context) Stream<Object?>
Invokes the function with the given args.
override
executeSync(JsonMap args, ExecutionContext context) Object?
Executes the function synchronously.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited