UiPartConstants class abstract final

Constants for UI related parts.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

interactionMimeType → const String
MIME type for UI interaction parts.
uiMimeType → const String
MIME type for UI definition parts.