UpdateComponents class final

An A2UI message that updates a surface with new components.

Inheritance

Constructors

UpdateComponents({required String surfaceId, required List<Component> components})
Creates a UpdateComponents message.
const
UpdateComponents.fromJson(JsonMap json)
Creates a UpdateComponents message from a JSON map.
factory

Properties

components List<Component>
The list of components to add or update.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceId String
The ID of the surface that this message applies to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this message to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited