UserActionEvent extension type

A UI event that represents a user action.

Triggers a submission to the AI, such as tapping a button.

on
Implemented types

Constructors

UserActionEvent({String? surfaceId, required String name, required String sourceComponentId, DateTime? timestamp, JsonMap? context})
Creates a UserActionEvent from a set of properties.
UserActionEvent.fromMap(JsonMap _json)

Properties

context JsonMap
Context associated with the action.
no setter
eventType String
The type of event that was triggered (e.g., 'onChanged', 'onTap').
no setterinherited
name String
The name of the action.
no setter
sourceComponentId String
The ID of the component that triggered the action.
no setter
surfaceId String
The ID of the surface that this event originated from.
no setterinherited
timestamp DateTime
The timestamp of when the event occurred.
no setterinherited
value Object?
The value associated with the event, if any.
no setterinherited
widgetId String
The ID of the widget that triggered the event.
no setterinherited

Methods

toMap() JsonMap
Converts this event to a map, suitable for JSON serialization.
inherited