DataModelTypeException class
Exception thrown when a value in the DataModel is not of the expected type.
- Implemented types
Constructors
- DataModelTypeException({required DataPath path, required Type expectedType, required Type actualType})
- Creates a DataModelTypeException.
Properties
- actualType → Type
-
The actual type found.
final
- expectedType → Type
-
The expected type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → DataPath
-
The path where the type mismatch occurred.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited