InlineCatalogHandling enum
Defines how catalogs should be handled when generating client capabilities.
Values
- none → const InlineCatalogHandling
-
Do not inline any catalogs. If a catalog is missing a
catalogId, an exception is thrown. - missingIds → const InlineCatalogHandling
-
Inline only catalogs that do not have a
catalogId. Send the rest as supported IDs. - all → const InlineCatalogHandling
-
Inline all provided catalogs, regardless of whether they have a
catalogId.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InlineCatalogHandling> - A constant List of the values in this enum, in order of their declaration.