ProtocolMessages enum
- Inheritance
- Available extensions
- Annotations
Values
- createSurface → const ProtocolMessages
-
const ProtocolMessages(name: 'createSurface', explanation: 'Creates a new surface.', properties: ''' Requires `surfaceId` (you must always use a unique ID for each created … - updateComponents → const ProtocolMessages
-
const ProtocolMessages(name: 'updateComponents', explanation: 'Updates components in a surface.', properties: ''' Requires `surfaceId` and a list of `components`. One compo… - updateDataModel → const ProtocolMessages
-
const ProtocolMessages(name: 'updateDataModel', explanation: 'Updates the data model.', properties: ''' Requires `surfaceId`, `path` and `value`. ''') - deleteSurface → const ProtocolMessages
-
const ProtocolMessages(name: 'deleteSurface', explanation: 'Deletes a surface.', properties: ''' Requires `surfaceId`. ''')
Properties
- explanation → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - properties → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tickedName → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
explainMessages(
Set< ProtocolMessages> operations) → String
Constants
-
values
→ const List<
ProtocolMessages> - A constant List of the values in this enum, in order of their declaration.