StandardPart class sealed
Base class for parts that became de-facto standard for AI messages.
It is sealed to prevent extensions.
- Inheritance
- Available extensions
Constructors
-
StandardPart.fromJson(Map<
String, Object?> json) -
Deserializes a part from a JSON map.
factory
Properties
- asUiInteractionPart → UiInteractionPart?
-
Available on StandardPart, provided by the UiPartExtension extension
Returns this part as a UiInteractionPart view.no setter - asUiPart → UiPart?
-
Available on StandardPart, provided by the UiPartExtension extension
Returns this part as a UiPart view, if generic type checks out.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isUiInteractionPart → bool
-
Available on StandardPart, provided by the UiPartExtension extension
Whether this part is a UI interaction part.no setter - isUiPart → bool
-
Available on StandardPart, provided by the UiPartExtension extension
Whether this part is a UI part.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Serializes the part to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited