SurfaceOperations class final
Pieces of prompt that defines allowed surface operations.
Constructors
- SurfaceOperations({bool create = false, bool update = false, bool delete = false, bool dataModel = false})
- SurfaceOperations.all({required bool dataModel})
- SurfaceOperations.createAndUpdate({required bool dataModel})
- SurfaceOperations.createOnly({required bool dataModel})
- SurfaceOperations.updateOnly({required bool dataModel})
Properties
- create → bool
-
final
- dataModel → bool
-
final
- delete → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
systemPromptFragments
→ Iterable<
String> -
System prompt fragment related to the surface operations.
latefinal
- update → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited