ThinkingPart class final
A "thinking" part of a message, used by some models to show reasoning.
- Inheritance
-
- Object
- Part
- StandardPart
- ThinkingPart
- Available extensions
- Annotations
Constructors
- ThinkingPart(String text)
-
Creates a thinking part.
const
-
ThinkingPart.fromJson(Map<
String, Object?> json) -
Creates a thinking part from a JSON map.
factory
Properties
- asUiInteractionPart → UiInteractionPart?
-
Available on StandardPart, provided by the UiPartExtension extension
Returns this part as a UiInteractionPart view.no setter - asUiPart → UiPart?
-
Available on StandardPart, provided by the UiPartExtension extension
Returns this part as a UiPart view, if generic type checks out.no setter - hashCode → int
-
The hash code for this object.
no setteroverride
- isUiInteractionPart → bool
-
Available on StandardPart, provided by the UiPartExtension extension
Whether this part is a UI interaction part.no setter - isUiPart → bool
-
Available on StandardPart, provided by the UiPartExtension extension
Whether this part is a UI part.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The thinking content.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Serializes the part to a JSON map.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override