An interface for transporting messages between GenUI and an AI service.
This unifies the concept of incoming streams (text chunks and A2UI messages) and outgoing requests.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
incomingMessages
→ Stream<
A2uiMessage> -
A stream of parsed A2uiMessages received from the AI service.
no setter
-
incomingText
→ Stream<
String> -
A stream of raw text chunks received from the AI service.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Disposes of any resources used by this transport.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendRequest(
ChatMessage message) → Future< void> - Sends a request to the AI service.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited