UpdateDataModel class final
An A2UI message that updates the data model.
- Inheritance
-
- Object
- A2uiMessage
- UpdateDataModel
Constructors
- UpdateDataModel({required String surfaceId, DataPath path = DataPath.root, Object? value})
-
Creates a UpdateDataModel message.
const
- UpdateDataModel.fromJson(JsonMap json)
-
Creates a UpdateDataModel message from a JSON map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → DataPath
-
The path in the data model to update. Defaults to root '/'.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surfaceId → String
-
The ID of the surface that this message applies to.
final
- value → Object?
-
The new value to write to the data model.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this message to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited